@@ -40,9 +40,8 @@ class Query:
 
     task_query: Optional[TaskQuery] = None
     task_id_set: Optional[Set[str]] = None
-    """集計対象タスクのtask_idのSet"""
     ignored_task_id_set: Optional[Set[str]] = None
-    """集計対象外タスクのtask_idのSet"""
+    """集計対象タスクのtask_idのSet"""
     start_date: Optional[str] = None
     end_date: Optional[str] = None
 
@@ -77,29 +76,26 @@ class Database:
         self,
         annofab_service: annofabapi.Resource,
         project_id: str,
-        checkpoint_dir: str,
+        temp_dir: Path,
         query: Optional[Query] = None,
-        is_get_labor: bool = False,
     ):
         """
         環境変数'ANNOFAB_USER_ID', 'ANNOFAB_PASSWORD'から情報を読み込み、AnnofabApiインスタンスを生成する。
         Args:
             project_id: Annofabのproject_id
-            is_get_labor: labor関係のwebapiにアクセスしてlabor情報を取得するかどうか。
         """
 
         self.annofab_service = annofab_service
         self.project_id = project_id
-        self.checkpoint_dir = checkpoint_dir
+        self.temp_dir = temp_dir
         self.query = query if query is not None else Query()
-        self.is_get_labor = is_get_labor
 
         # ダウンロードした一括情報
-        self.tasks_json_path = Path(f"{self.checkpoint_dir}/tasks.json")
-        self.input_data_json_path = Path(f"{self.checkpoint_dir}/input_data.json")
-        self.inspection_json_path = Path(f"{self.checkpoint_dir}/inspections.json")
-        self.task_histories_json_path = Path(f"{self.checkpoint_dir}/task_histories.json")
-        self.annotations_zip_path = Path(f"{self.checkpoint_dir}/simple-annotations.zip")
+        self.tasks_json_path = self.temp_dir / "tasks.json"
+        self.input_data_json_path = temp_dir / "input_data.json"
+        self.inspection_json_path = temp_dir / "inspections.json"
+        self.task_histories_json_path = temp_dir / "task_histories.json"
+        self.annotations_zip_path = temp_dir / "simple-annotations.zip"
 
         self.logging_prefix = f"project_id={project_id}"
 
@@ -531,26 +527,6 @@ class Database:
         self._download_db_file(is_latest, is_get_task_histories_one_of_each=is_get_task_histories_one_of_each)
         self._log_annotation_zip_info()
 
-    def get_labor_list(self, project_id: str) -> List[Dict[str, Any]]:
-        def to_new_labor(e: Dict[str, Any]) -> Dict[str, Any]:
-            e["actual_worktime_hour"] = e["actual_worktime"]
-            e.pop("actual_worktime")
-            e.pop("plan_worktime")
-            return e
-
-        if not self.is_get_labor:
-            return []
-
-        # 未来のデータを取得しても意味がないので、今日の日付を指定する
-        end_date = (
-            self.query.end_date if self.query.end_date is not None else datetime.datetime.now().strftime("%Y-%m-%d")
-        )
-        labor_list: List[Dict[str, Any]] = self.annofab_service.wrapper.get_labor_control_worktime(
-            project_id=project_id, from_date=self.query.start_date, to_date=end_date
-        )
-
-        return [to_new_labor(e) for e in labor_list]
-
     def get_task_histories_dict(self, all_tasks: List[Task]) -> Dict[str, List[TaskHistory]]:
         """
         Annofabからタスク履歴情報を取得する。
